Enum aws_sdk_honeycode::error::BatchUpsertTableRowsErrorKind[][src]

#[non_exhaustive]
pub enum BatchUpsertTableRowsErrorKind {
    AccessDeniedException(AccessDeniedException),
    InternalServerException(InternalServerException),
    RequestTimeoutException(RequestTimeoutException),
    ResourceNotFoundException(ResourceNotFoundException),
    ServiceQuotaExceededException(ServiceQuotaExceededException),
    ServiceUnavailableException(ServiceUnavailableException),
    ThrottlingException(ThrottlingException),
    ValidationException(ValidationException),
    Unhandled(Box<dyn Error + Send + Sync + 'static>),
}
Types of errors that can occur for the BatchUpsertTableRows operation.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
AccessDeniedException(AccessDeniedException)

You do not have sufficient access to perform this action. Check that the workbook is owned by you and your IAM policy allows access to the resource in the request.

Tuple Fields of AccessDeniedException

0: AccessDeniedException
InternalServerException(InternalServerException)

There were unexpected errors from the server.

Tuple Fields of InternalServerException

0: InternalServerException
RequestTimeoutException(RequestTimeoutException)

The request timed out.

Tuple Fields of RequestTimeoutException

0: RequestTimeoutException
ResourceNotFoundException(ResourceNotFoundException)

A Workbook, Table, App, Screen or Screen Automation was not found with the given ID.

Tuple Fields of ResourceNotFoundException

0: ResourceNotFoundException
ServiceQuotaExceededException(ServiceQuotaExceededException)

The request caused service quota to be breached.

Tuple Fields of ServiceQuotaExceededException

0: ServiceQuotaExceededException
ServiceUnavailableException(ServiceUnavailableException)

Remote service is unreachable.

Tuple Fields of ServiceUnavailableException

0: ServiceUnavailableException
ThrottlingException(ThrottlingException)

Tps(transactions per second) rate reached.

Tuple Fields of ThrottlingException

0: ThrottlingException
ValidationException(ValidationException)

Request is invalid. The message in the response contains details on why the request is invalid.

Tuple Fields of ValidationException

0: ValidationException
Unhandled(Box<dyn Error + Send + Sync + 'static>)

An unexpected error, eg. invalid JSON returned by the service or an unknown error code

Tuple Fields of Unhandled

0: Box<dyn Error + Send + Sync + 'static>