Enum aws_sdk_honeycode::error::QueryTableRowsErrorKind [−][src]
#[non_exhaustive]
pub enum QueryTableRowsErrorKind {
AccessDeniedException(AccessDeniedException),
InternalServerException(InternalServerException),
RequestTimeoutException(RequestTimeoutException),
ResourceNotFoundException(ResourceNotFoundException),
ServiceUnavailableException(ServiceUnavailableException),
ThrottlingException(ThrottlingException),
ValidationException(ValidationException),
Unhandled(Box<dyn Error + Send + Sync + 'static>),
}Expand description
Types of errors that can occur for the QueryTableRows operation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
AccessDeniedException(AccessDeniedException)You do not have sufficient access to perform this action. Check that the workbook is owned by you and your IAM policy allows access to the resource in the request.
Tuple Fields of AccessDeniedException
InternalServerException(InternalServerException)There were unexpected errors from the server.
Tuple Fields of InternalServerException
RequestTimeoutException(RequestTimeoutException)The request timed out.
Tuple Fields of RequestTimeoutException
ResourceNotFoundException(ResourceNotFoundException)A Workbook, Table, App, Screen or Screen Automation was not found with the given ID.
Tuple Fields of ResourceNotFoundException
Remote service is unreachable.
ThrottlingException(ThrottlingException)Tps(transactions per second) rate reached.
Tuple Fields of ThrottlingException
ValidationException(ValidationException)Request is invalid. The message in the response contains details on why the request is invalid.
Tuple Fields of ValidationException
An unexpected error, eg. invalid JSON returned by the service or an unknown error code