Struct aws_sdk_honeycode::output::BatchUpsertTableRowsOutput [−][src]
#[non_exhaustive]pub struct BatchUpsertTableRowsOutput {
pub rows: Option<HashMap<String, UpsertRowsResult>>,
pub workbook_cursor: i64,
pub failed_batch_items: Option<Vec<FailedBatchItem>>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.rows: Option<HashMap<String, UpsertRowsResult>>A map with the batch item id as the key and the result of the upsert operation as the value. The result of the upsert operation specifies whether existing rows were updated or a new row was appended, along with the list of row ids that were affected.
workbook_cursor: i64The updated workbook cursor after updating or appending rows in the table.
failed_batch_items: Option<Vec<FailedBatchItem>>The list of batch items in the request that could not be updated or appended in the table. Each element in this list contains one item from the request that could not be updated in the table along with the reason why that item could not be updated or appended.
Implementations
Creates a new builder-style object to manufacture BatchUpsertTableRowsOutput