Struct aws_sdk_honeycode::client::Client [−][src]
pub struct Client<C = DynConnector, M = AwsMiddleware, R = Standard> { /* fields omitted */ }Expand description
An ergonomic service client for SheetsPublicApiService.
This client allows ergonomic access to a SheetsPublicApiService-shaped service.
Each method corresponds to an endpoint defined in the service’s Smithy model,
and the request and response shapes are auto-generated from that same model.
Using a Client
Once you have a client set up, you can access the service’s endpoints
by calling the appropriate method on Client. Each such method
returns a request builder for that endpoint, with methods for setting
the various fields of the request. Once your request is complete, use
the send method to send the request. send returns a future, which
you then have to .await to get the service’s response.
Implementations
impl<C, M, R> Client<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
impl<C, M, R> Client<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
Constructs a fluent builder for the BatchCreateTableRows operation.
See BatchCreateTableRows for more information about the
operation and its arguments.
Constructs a fluent builder for the BatchDeleteTableRows operation.
See BatchDeleteTableRows for more information about the
operation and its arguments.
Constructs a fluent builder for the BatchUpdateTableRows operation.
See BatchUpdateTableRows for more information about the
operation and its arguments.
Constructs a fluent builder for the BatchUpsertTableRows operation.
See BatchUpsertTableRows for more information about the
operation and its arguments.
Constructs a fluent builder for the DescribeTableDataImportJob operation.
See DescribeTableDataImportJob for more information about the
operation and its arguments.
Constructs a fluent builder for the GetScreenData operation.
See GetScreenData for more information about the
operation and its arguments.
Constructs a fluent builder for the InvokeScreenAutomation operation.
See InvokeScreenAutomation for more information about the
operation and its arguments.
Constructs a fluent builder for the ListTableColumns operation.
See ListTableColumns for more information about the
operation and its arguments.
Constructs a fluent builder for the ListTableRows operation.
See ListTableRows for more information about the
operation and its arguments.
Constructs a fluent builder for the ListTables operation.
See ListTables for more information about the
operation and its arguments.
Constructs a fluent builder for the QueryTableRows operation.
See QueryTableRows for more information about the
operation and its arguments.
Constructs a fluent builder for the StartTableDataImportJob operation.
See StartTableDataImportJob for more information about the
operation and its arguments.
Creates a client with the given service config and connector override.