Enum aws_sdk_honeycode::Error [−][src]
#[non_exhaustive]
pub enum Error {
AccessDeniedException(AccessDeniedException),
AutomationExecutionException(AutomationExecutionException),
AutomationExecutionTimeoutException(AutomationExecutionTimeoutException),
InternalServerException(InternalServerException),
RequestTimeoutException(RequestTimeoutException),
ResourceNotFoundException(ResourceNotFoundException),
ServiceQuotaExceededException(ServiceQuotaExceededException),
ServiceUnavailableException(ServiceUnavailableException),
ThrottlingException(ThrottlingException),
ValidationException(ValidationException),
Unhandled(Box<dyn Error + Send + Sync + 'static>),
}Expand description
All possible error types for this service.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
AccessDeniedException(AccessDeniedException)You do not have sufficient access to perform this action. Check that the workbook is owned by you and your IAM policy allows access to the resource in the request.
Tuple Fields of AccessDeniedException
AutomationExecutionException(AutomationExecutionException)The automation execution did not end successfully.
Tuple Fields of AutomationExecutionException
AutomationExecutionTimeoutException(AutomationExecutionTimeoutException)The automation execution timed out.
Tuple Fields of AutomationExecutionTimeoutException
InternalServerException(InternalServerException)There were unexpected errors from the server.
Tuple Fields of InternalServerException
RequestTimeoutException(RequestTimeoutException)The request timed out.
Tuple Fields of RequestTimeoutException
ResourceNotFoundException(ResourceNotFoundException)A Workbook, Table, App, Screen or Screen Automation was not found with the given ID.
Tuple Fields of ResourceNotFoundException
ServiceQuotaExceededException(ServiceQuotaExceededException)The request caused service quota to be breached.
Tuple Fields of ServiceQuotaExceededException
Remote service is unreachable.
ThrottlingException(ThrottlingException)Tps(transactions per second) rate reached.
Tuple Fields of ThrottlingException
ValidationException(ValidationException)Request is invalid. The message in the response contains details on why the request is invalid.
Tuple Fields of ValidationException
An unhandled error occurred.